@@ -273,11 +273,7 @@ static QVariant createInstance(const QJsonObject& obj, const QString &type)
         return QLatin1String(lhs.name) < rhs;
     });
     if (it != registry.end() && QLatin1String((*it).name) == type) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        QVariant value((*it).metaTypeId, nullptr);
-#else
         QVariant value(QMetaType((*it).metaTypeId), nullptr);
-#endif
         createInstance((*it).mo, value.data(), obj);
         return value;
     }
@@ -306,11 +302,7 @@ static QVariant createInstance(const QJsonObject &obj, const QMetaProperty &prop
     // if @type is (wrongly) not specified, try to recover from our own knowledge of a property type
     const auto mo = QMetaType(prop.userType()).metaObject();
     if (mo) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        QVariant value(prop.userType(), nullptr);
-#else
         QVariant value(prop.metaType(), nullptr);
-#endif
         createInstance(mo, value.data(), obj);
         return value;
     }
@@ -318,9 +310,8 @@ static QVariant createInstance(const QJsonObject &obj, const QMetaProperty &prop
     return {};
 }
 
-QVector<QVariant> JsonLdDocument::fromJson(const QJsonArray &array)
-{
-    QVector<QVariant> l;
+QList<QVariant> JsonLdDocument::fromJson(const QJsonArray &array) {
+    QList<QVariant> l;
     l.reserve(array.size());
     for (const auto &obj : array) {
         l.append(JsonLdDocument::fromJson(obj.toObject()));
@@ -328,10 +319,9 @@ QVector<QVariant> JsonLdDocument::fromJson(const QJsonArray &array)
     return l;
 }
 
-QVector<QVariant> JsonLdDocument::fromJson(const QJsonObject &obj)
-{
+QList<QVariant> JsonLdDocument::fromJson(const QJsonObject &obj) {
     const auto normalized = JsonLdImportFilter::filterObject(obj);
-    QVector<QVariant> result;
+    QList<QVariant> result;
     result.reserve(normalized.size());
     for (const auto &n : normalized) {
         const auto v = createInstance(n.toObject());
@@ -358,6 +348,8 @@ bool JsonLd::valueIsNull(const QVariant &v)
             return !v.toUrl().isValid();
         case QMetaType::Float:
             return std::isnan(v.toFloat());
+        case QMetaType::Double:
+            return std::isnan(v.toDouble());
         case QMetaType::QVariantList:
             return v.toList().isEmpty();
         // starting with Qt6, QVariant::isNull is "shallow" and would miss the following as well
@@ -476,8 +468,7 @@ QJsonValue JsonLdDocument::toJsonValue(const QVariant &v)
     return {};
 }
 
-QJsonArray JsonLdDocument::toJson(const QVector<QVariant> &data)
-{
+QJsonArray JsonLdDocument::toJson(const QList<QVariant> &data) {
     QJsonArray a;
     for (const auto &d : data) {
         const auto value = toJsonValue(d);
@@ -591,11 +582,7 @@ QVariant JsonLdDocument::apply(const QVariant& lhs, const QVariant& rhs)
             }
             auto valueData = mt.create();
             *reinterpret_cast<int*>(valueData) = numValue;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            QVariant value(prop.userType(), valueData);
-#else
             QVariant value(prop.metaType(), valueData);
-#endif
             prop.writeOnGadget(res.data(), value);
             continue;
         }
