@@ -141,8 +141,8 @@ function parseTicket(text, uic918ticket) {
 
         // for outward journeys we have station ids from the UIC 918-3 code
         if (uic918ticket && header[1] !== "Rück") {
-            reservations[0].reservationFor.departureStation = JsonLd.apply(JsonLd.toJson(uic918ticket.outboundDepartureStation), reservations[0].reservationFor.departureStation);
-            reservations[reservations.length - 1].reservationFor.arrivalStation = JsonLd.apply(JsonLd.toJson(uic918ticket.outboundArrivalStation), reservations[reservations.length - 1].reservationFor.arrivalStation);
+            reservations[0].reservationFor.departureStation.identifier = uic918ticket.outboundDepartureStation.identifier;
+            reservations[reservations.length - 1].reservationFor.arrivalStation.identifier = uic918ticket.outboundArrivalStation.identifier;
             returnResIndex = reservations.length;
         } else {
             // propagate station ids from outward to return journey
@@ -163,7 +163,8 @@ function parseTicket(text, uic918ticket) {
 
     // international tickets have the booking reference somewhere on the side, so we don't really know
     // where it is relative to the itinerary
-    const bookingRef = text.match(/(?:Auftragsnummer|Auftrag \(NVS\)):\s*([A-Z0-9]{6,9}|\d{12})\n/);
+    const bookingRef = text.match(/(?:Auftragsnummer|Auftrag \(NVS\)):\s*([A-Z0-9]{6,9})\n/);
+    const price = text.match(/(?:Summe|Gesamtpreis) *(\d+,\d{2} ?€)/)[1];
     for (var i = 0; i < reservations.length; ++i) {
         if (bookingRef) {
             reservations[i].reservationNumber = bookingRef[1];
@@ -173,6 +174,7 @@ function parseTicket(text, uic918ticket) {
             reservations[i] = JsonLd.trainToBusReservation(reservations[i]);
             reservations[i].reservedTicket.ticketedSeat = undefined;
         }
+        ExtractorEngine.extractPrice(price, reservations[i]);
     }
     return reservations;
 }
@@ -185,11 +187,11 @@ function parseReservation(pdf) {
     while (true) {
         var dep = text.substr(idx).match(/  (\S.*\S) +(\d\d.\d\d.\d\d) +ab (\d\d:\d\d)  +(.*?)  +([A-Z].*\S)  +(.*)\n/);
         if (!dep)
-            return reservations;
+            break;
         idx += dep.index + dep[0].length;
         var arr = text.substr(idx).match(/  (\S.*\S) +an (\d\d:\d\d)  +(.*?)  +(.*)\n/);
         if (!arr)
-            return reservations;
+            break;
 
         var res = JsonLd.newTrainReservation();
         res.reservationFor.departureStation.name = dep[1];
@@ -212,16 +214,14 @@ function parseReservation(pdf) {
         idx += arr.index + arr[0].length;
     }
 
+    ExtractorEngine.extractPrice(text, reservations);
     return reservations;
 }
 
 function applyUic9183ToReservation(res, uicNode)
 {
     const uicCode = uicNode.content;
-    if (!res.reservationNumber || res.reservationNumber == uicCode.pnr)
-        res.reservationNumber = uicCode.pnr;
-    else
-        res.reservedTicket.ticketNumber = uicCode.pnr;
+    res.reservationNumber = uicCode.pnr;
     res.reservationFor.provider = JsonLd.toJson(uicCode.issuer);
     if (uicNode.result.length > 0 && uicNode.result[0].programMembershipUsed)
         res.programMembershipUsed = uicNode.result[0].programMembershipUsed;
