@@ -8,10 +8,13 @@
 #include "logging.h"
 #include "uic9183ticketlayout.h"
 
+#include <text/pricefinder_p.h>
+
 #include <QDateTime>
 #include <QDebug>
 #include <QRegularExpression>
 
+#include <cmath>
 #include <cstring>
 
 using namespace KItinerary;
@@ -218,11 +221,7 @@ QDateTime Rct2Ticket::outboundDepartureTime() const
 
 QDateTime Rct2Ticket::outboundArrivalTime() const
 {
-    auto dt = d->parseTime(d->layout.text(6, 52, 5, 1).trimmed(), d->layout.text(6, 58, 5, 1).trimmed());
-    if (dt.isValid() && dt < outboundDepartureTime()) {
-        dt = dt.addYears(1);
-    }
-    return dt;
+    return d->parseTime(d->layout.text(6, 52, 5, 1).trimmed(), d->layout.text(6, 58, 5, 1).trimmed());
 }
 
 static QString rct2Clean(const QString &s)
@@ -265,11 +264,7 @@ QDateTime Rct2Ticket::returnDepartureTime() const
 
 QDateTime Rct2Ticket::returnArrivalTime() const
 {
-    auto dt = d->parseTime(d->layout.text(7, 52, 5, 1).trimmed(), d->layout.text(7, 58, 5, 1).trimmed());
-    if (dt.isValid() && dt < returnDepartureTime()) {
-        dt = dt.addYears(1);
-    }
-    return dt;
+    return d->parseTime(d->layout.text(7, 52, 5, 1).trimmed(), d->layout.text(7, 58, 5, 1).trimmed());
 }
 
 QString Rct2Ticket::returnDepartureStation() const
@@ -349,3 +344,22 @@ QString Rct2Ticket::seatNumber() const
     }
     return {};
 }
+
+QString Rct2Ticket::currency() const
+{
+    std::vector<PriceFinder::Result> result;
+    PriceFinder finder;
+    finder.findAll(d->layout.text(13, 52, 19, 1).remove(QLatin1Char('*')), result);
+    return result.size() == 1 ? result[0].currency : QString();
+}
+
+double Rct2Ticket::price() const
+{
+    std::vector<PriceFinder::Result> result;
+    PriceFinder finder;
+    finder.findAll(d->layout.text(13, 52, 19, 1).remove(QLatin1Char('*')), result);
+    return result.size() == 1 ? result[0].value : NAN;
+}
+
+#include "moc_rct2ticket.cpp"
+
